@@ -1,12 +1,12 @@
 package Tibco::Rv::Inline;
 
 
-use vars qw/ $VERSION $TIBRV_VERSION_RELEASE %CONFIG /;
+use vars qw/ $VERSION $TIBRV_VERSION_RELEASE $TIBRV_VERSION_MINOR %CONFIG /;
 
 
 BEGIN
 {
-   $VERSION = '1.13';
+   $VERSION = '1.14';
    my ( $env_err ) = q/
 one of: TIB_HOME, TIB_RV_HOME, or TIBRV_DIR must be set
 TIB_HOME must be your base Tibco directory, and it must contain "tibrv"; or:
@@ -23,23 +23,22 @@ TIB_RV_HOME or TIBRV_DIR must be your Rendezvous installation directory
    }
    die $env_err
       unless ( -d "$ENV{TIB_RV_HOME}/include" and -d "$ENV{TIB_RV_HOME}/lib" );
-   ( $TIBRV_VERSION_RELEASE ) =
+   ( $TIBRV_VERSION_RELEASE, $TIBRV_VERSION_MINOR ) =
       scalar( `$ENV{TIB_RV_HOME}/bin/rvd --not-really-a-thing 2>/dev/null` )
-         =~ /Version (\d+)\./g;
+         =~ /Version (\d+)\.(\d+)./g;
    die "Could not find rvd 6.x or 7.x"
       unless ( $TIBRV_VERSION_RELEASE == 6 or $TIBRV_VERSION_RELEASE == 7 );
 
    %CONFIG =
    (
-#fixme (pthread x 2)
       AUTO_INCLUDE => <<END,
 #include <tibrv/cm.h>
-#include <pthread.h>
 #define TIBRV_VERSION_RELEASE $TIBRV_VERSION_RELEASE
+#define TIBRV_VERSION_MINOR $TIBRV_VERSION_MINOR
 END
       AUTOWRAP => 'ENABLE',
       TYPEMAPS => 'typemap',
-      LIBS => "-L$ENV{TIB_RV_HOME}/lib -ltibrv -ltibrvcm -lpthread",
+      LIBS => "-L$ENV{TIB_RV_HOME}/lib -ltibrv -ltibrvcm",
       INC => "-I$ENV{TIB_RV_HOME}/include",
    );
 }
